import { __esmMin } from "../rolldown-runtime.js";
import { createRule, init_ast, init_create_rule, isParenthesised } from "../utils.js";
/**
* Checks whether or not a node is a conditional expression.
* @param node node to test
* @returns `true` if the node is a conditional expression.
*/
function isConditional(node) {
	return node.type === "ConditionalExpression";
}
var no_confusing_arrow_default;
var init_no_confusing_arrow = __esmMin(() => {
	init_ast();
	init_create_rule();
	no_confusing_arrow_default = createRule({
		name: "no-confusing-arrow",
		meta: {
			type: "layout",
			docs: { description: "Disallow arrow functions where they could be confused with comparisons" },
			fixable: "code",
			schema: [{
				type: "object",
				properties: {
					allowParens: {
						type: "boolean",
						default: true
					},
					onlyOneSimpleParam: {
						type: "boolean",
						default: false
					}
				},
				additionalProperties: false
			}],
			messages: { confusing: "Arrow function used ambiguously with a conditional expression." }
		},
		create(context) {
			const config = context.options[0] || {};
			const allowParens = config.allowParens || config.allowParens === void 0;
			const onlyOneSimpleParam = config.onlyOneSimpleParam;
			const sourceCode = context.sourceCode;
			/**
			* Reports if an arrow function contains an ambiguous conditional.
			* @param node A node to check and report.
			*/
			function checkArrowFunc(node) {
				const body = node.body;
				if (isConditional(body) && !(allowParens && isParenthesised(sourceCode, body)) && !(onlyOneSimpleParam && !(node.params.length === 1 && node.params[0].type === "Identifier"))) context.report({
					node,
					messageId: "confusing",
					fix(fixer) {
						return allowParens ? fixer.replaceText(node.body, `(${sourceCode.getText(node.body)})`) : null;
					}
				});
			}
			return { ArrowFunctionExpression: checkArrowFunc };
		}
	});
});
export { init_no_confusing_arrow, no_confusing_arrow_default };
